# Introduction

**An interactive audio player with a spectrogram built-in, as a Jupyter widget or as HTML.**


```{toctree}    
:titlesonly:
:hidden:
:maxdepth: 2

Introduction <self>
Getting Started <getting_started>
User Guide <user_guide>
Gallery <gallery>
API <reference_manual>
FAQ <FAQ>
About <about>
```